==> haskell-data-functor-logistic-0.0-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-A081mw6HHd6PBCA11jJzk
key:                  data-functor-logistic-0.0-A081mw6HHd6PBCA11jJzk
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  cb18c6eed565e34968e00ac2a3c77ec1
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-A081mw6HHd6PBCA11jJzk
depends:
    base-4.17.2.1 distributive-0.6.2.1-EkCA849v7Xz7JjUK4vYFJS

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-functor-logistic-0.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-8MMkvLwibBy4QxqaAxXjU
key:                  data-functor-logistic-0.0-8MMkvLwibBy4QxqaAxXjU
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  5e39ddc6228004918654fbc1fb0136d8
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-8MMkvLwibBy4QxqaAxXjU
depends:
    base-4.17.2.1 distributive-0.6.2.1-AaJ1Rc5A0vxBwbHEYFEoTm

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
